pub enum ClientType {
TCP(RawClient<ElectrumPlaintextStream>),
SSL(RawClient<ElectrumSslStream>),
Socks5(RawClient<ElectrumProxyStream>),
}Expand description
Generalized Electrum client that supports multiple backends. This wraps
RawClient and provides a more user-friendly
constructor that can choose the right backend based on the url prefix.
Note the Socks5 client type requires the proxy feature to be enabled.
Variants
TCP(RawClient<ElectrumPlaintextStream>)
SSL(RawClient<ElectrumSslStream>)
Socks5(RawClient<ElectrumProxyStream>)
Implementations
Sourceimpl ClientType
impl ClientType