Enum electrum_client::Error [−][src]
pub enum Error {
Show 16 variants
IOError(Error),
JSON(Error),
Hex(Error),
Protocol(Value),
Bitcoin(Error),
AlreadySubscribed(ScriptHash),
NotSubscribed(ScriptHash),
InvalidResponse(Value),
Message(String),
InvalidDNSNameError(String),
MissingDomain,
AllAttemptsErrored(Vec<Error>),
SharedIOError(Arc<Error>),
BothSocksAndTimeout,
CouldntLockReader,
Mpsc,
}Expand description
Errors
Variants
Wraps std::io::Error
Tuple Fields of IOError
0: ErrorWraps serde_json::error::Error
Tuple Fields of JSON
0: ErrorWraps bitcoin::hashes::hex::Error
Error returned by the Electrum server
Tuple Fields of Protocol
0: ValueError during the deserialization of a Bitcoin data structure
Tuple Fields of Bitcoin
0: ErrorAlready subscribed to the notifications of an address
Tuple Fields of AlreadySubscribed
0: ScriptHashNot subscribed to the notifications of an address
Tuple Fields of NotSubscribed
0: ScriptHashError during the deserialization of a response from the server
Tuple Fields of InvalidResponse
0: ValueGeneric error with a message
Tuple Fields of Message
0: StringInvalid domain name for an SSL certificate
Tuple Fields of InvalidDNSNameError
0: StringMissing domain while it was explicitly asked to validate it
Made one or multiple attempts, always in Error
There was an io error reading the socket, to be shared between threads
Setting both a proxy and a timeout in Config is an error
Couldn’t take a lock on the reader mutex. This means that there’s already another reader thread running
Broken IPC communication channel: the other thread probably has exited