Module raw_client

Module raw_client 

Raw client

This module contains the definition of the raw client that wraps the transport method

Structs

RawClient
Instance of an Electrum client

Constants

CLIENT_NAME
Client name sent to the server during protocol version negotiation.
PROTOCOL_VERSION_MAX
Maximum protocol version supported by this client.
PROTOCOL_VERSION_MIN
Minimum protocol version supported by this client.

Traits

ToSocketAddrsDomain
A trait for ToSocketAddrs that can also be turned into a domain. Used when an SSL client needs to validate the server’s certificate.

Type Aliases

ElectrumPlaintextStream
Transport type used to establish a plaintext TCP connection with the server
ElectrumProxyStream
Transport type used to establish a connection to a server through a socks proxy
ElectrumSslStream
Transport type used to establish a Rustls TLS encrypted/authenticated connection with the server