pub type ElectrumProxyStream = Socks5Stream;Expand description
Transport type used to establish a connection to a server through a socks proxy
Aliased Type
struct ElectrumProxyStream { /* private fields */ }pub type ElectrumProxyStream = Socks5Stream;Transport type used to establish a connection to a server through a socks proxy
struct ElectrumProxyStream { /* private fields */ }