pub struct BroadcastPackageError {
pub txid: Txid,
pub error: String,
}Expand description
Error details for a transaction that failed to broadcast in a package.
Fields
txid: TxidThe txid of the transaction that failed.
error: StringThe error message describing why the transaction was rejected.