pub struct MempoolInfoRes {
pub mempoolminfee: f64,
pub minrelaytxfee: f64,
pub incrementalrelayfee: f64,
}Expand description
Response to a mempool_get_info request.
Contains information about the current state of the mempool.
Fields
mempoolminfee: f64Dynamic minimum fee rate in BTC/kvB for tx to be accepted given current conditions.
The maximum of minrelaytxfee and minimum mempool fee.
minrelaytxfee: f64Static operator-configurable minimum relay fee for transactions, in BTC/kvB.
incrementalrelayfee: f64Static operator-configurable minimum fee rate increment for mempool limiting or replacement, in BTC/kvB.