Enum electrum_client::client::ClientType[][src]

Generalized Electrum client that supports multiple backends. This wraps RawClient and provides a more user-friendly constructor that can choose the right backend based on the url prefix.

This is available only with the default features, or if proxy and one ssl implementation are enabled

Variants

TCP

Tuple Fields of TCP

0: RawClient<ElectrumPlaintextStream>
SSL

Tuple Fields of SSL

0: RawClient<ElectrumSslStream>
Socks5

Tuple Fields of Socks5

0: RawClient<ElectrumProxyStream>

Implementations

Constructor that supports multiple backends and allows configuration through the Config