pub enum EstimationMode {
Conservative,
Economical,
}Expand description
Fee estimation mode for estimate_fee.
This parameter was added in protocol v1.6 and is passed to bitcoind’s
estimatesmartfee RPC as the estimate_mode parameter.
Variants
Conservative
A conservative estimate potentially returns a higher feerate and is more likely to be sufficient for the desired target, but is not as responsive to short term drops in the prevailing fee market.
Economical
Economical fee estimate - potentially lower fees but may take longer to confirm.