Raw client
This module contains the definition of the raw client that wraps the transport method
Structs
- RawClient
- Instance of an Electrum client
Constants
- CLIENT_
NAME - Client name sent to the server during protocol version negotiation.
- PROTOCOL_
VERSION_ MAX - Maximum protocol version supported by this client.
- PROTOCOL_
VERSION_ MIN - Minimum protocol version supported by this client.
Traits
- ToSocket
Addrs Domain - A trait for
ToSocketAddrsthat can also be turned into a domain. Used when an SSL client needs to validate the server’s certificate.
Type Aliases
- Electrum
Plaintext Stream - Transport type used to establish a plaintext TCP connection with the server
- Electrum
Proxy Stream - Transport type used to establish a connection to a server through a socks proxy
- Electrum
SslStream - Transport type used to establish a Rustls TLS encrypted/authenticated connection with the server